DeviceInfoMonitor class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAvailableMemory(
) → Future< String> -
getAvailableStorage(
) → Future< String> -
getBatteryLevel(
) → Future< int> -
getBatteryTemperature(
) → Future< String> -
getCpuTemperature(
) → Future< String> -
getCpuUsage(
) → Future< String> -
getDeviceModel(
) → Future< String> -
getSdkVersion(
) → Future< String> -
getTotalMemory(
) → Future< String> -
getTotalStorage(
) → Future< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited